__version__ = "0.0.8"

"""
Changelog:
0.0.8: Updated the testbase class to handle relative paths correctly
0.0.7: Testbase remote fix
0.0.6: Versioning weirdness
0.0.5: Fix rel path error
0.0.4: Add Base test class for sandboxed tests
0.0.3: Change to the way lfs looks for files- has a greater chance of finding
    them now.
0.0.2: Change order of arguments- allows users to put they tests in more
    places, i.e.doesn't restrict to data/'type' anymore
0.0.1: Initial version. Probably buggy
"""
